@@ -23,7 +23,6 @@ import enum
 import logging
 import re
 import string
-import tempfile
 
 import ply.lex as lex
 import ply.yacc as yacc
@@ -179,7 +178,7 @@ class Parser:
         self.import_effects = import_effects
 
         self.lexer = lex.lex(module=self, debug=False)
-        self.parser = yacc.yacc(module=self, debug=False, outputdir=tempfile.gettempdir())
+        self.parser = yacc.yacc(module=self, debug=False)
 
         self._testmode = testmode
         if testmode:
@@ -210,7 +209,7 @@ class Parser:
         self._stringnames.clear()
 
         self.lexer = lex.lex(module=self, debug=False)
-        self.parser = yacc.yacc(module=self, debug=False, outputdir=tempfile.gettempdir())
+        self.parser = yacc.yacc(module=self, debug=False)
 
     def _add_element(self, element_type, element_value):
         """Accept elements from the parser and uses them to construct a representation of the YARA rule.
@@ -627,14 +626,18 @@ class Plyara(Parser):
 
             return t
 
+    @staticmethod
+    def t_BYTESTRING_NEWLINE(t):
+        r'(\n|\r\n)+'  # noqa: D300, D400, D415
+        t.lexer.lineno += t.value.count('\n')
+
     @staticmethod
     def t_BYTESTRING_pair(t):
-        r'\s*~?[a-fA-F0-9?]{2}\s*'  # noqa: D300, D400, D415
+        r'[\t ]*~?[a-fA-F0-9?]{2}[\t ]*'  # noqa: D300, D400, D415
 
     @staticmethod
     def t_BYTESTRING_comment(t):
         r'\/\/[^\r\n]*'  # noqa: D300, D400, D415
-        t.lexer.lineno += 1
         t.type = 'COMMENT'
 
         return t
@@ -690,15 +693,9 @@ class Plyara(Parser):
 
         t.lexer.begin('INITIAL')
 
-        # Account for newlines in bytestring.
-        if '\r\n' in t.value:
-            t.lexer.lineno += t.value.count('\r\n')
-        else:
-            t.lexer.lineno += t.value.count('\n')
-
         return t
 
-    t_BYTESTRING_ignore = ' \r\n\t'
+    t_BYTESTRING_ignore = ' \t'
 
     @staticmethod
     def t_BYTESTRING_error(t):
@@ -974,7 +971,7 @@ class Plyara(Parser):
         key = p[1]
         value = p[3]
         if re.match(r'".*"', value):
-            value = p[3].strip('"')
+            value = p[3].removeprefix('"').removesuffix('"')
         elif value in ('true', 'false'):
             value = True if value == 'true' else False
         elif value == '-':
